@@ -1,10 +1,11 @@
 from askdata import query2sql
 from askdata.smartquery import SmartQuery, Query, Field, Condition, Sorting, SQLSorting, SQLOperator, TimeOperator, \
     BooleanOperator, CompositeCondition
+import pandas as pd
 
 if __name__ == "__main__":
 
-    # # Query2SQL
+    # Query2SQL
     smartquery = SmartQuery(
         queries=[
             Query(
@@ -60,8 +61,19 @@ if __name__ == "__main__":
     db_driver = "olap"
 
     # Function call
-    result_nl = query2sql.query_to_olap(nl=nl, df=df, schema=schema, db_driver=db_driver)
+    result_for_ner = query2sql.prepare_ner(nl=nl, schema=schema, db_driver=db_driver)
+    smartquery = query2sql.query_to_smartquery(result_for_ner)
+    olap_query = query2sql.smartquery_to_olap(smartquery)
 
     # Print the DataFrame result
     print("Answer: ")
-    print(result_nl)
+    print(result_for_ner)
+    print("#----#")
+    print(smartquery)
+    print("#----#")
+    print(olap_query)
+
+    # All
+    response = query2sql.query_to_olap(nl=nl, schema=schema, db_driver=db_driver)
+    print("Answer: ")
+    print(response)
